package com.ruoyi.system.service.columns;

import com.ruoyi.system.domain.columns.YjStore;

import java.util.List;

/**
 * 门店Service接口
 *
 * @author ruoyi
 * @date 2025-10-31
 */
public interface IYjStoreService
{
    /**
     * 查询门店
     *
     * @param deptId 门店主键
     * @return 门店
     */
    public YjStore selectYjStoreByDeptId(Long deptId);

    /**
     * 查询门店列表
     *
     * @param yjStore 门店
     * @return 门店集合
     */
    public List<YjStore> selectYjStoreList(YjStore yjStore);

    /**
     * 新增门店
     *
     * @param yjStore 门店
     * @return 结果
     */
    public int insertYjStore(YjStore yjStore);

    /**
     * 修改门店
     *
     * @param yjStore 门店
     * @return 结果
     */
    public int updateYjStore(YjStore yjStore);

    /**
     * 批量删除门店
     *
     * @param deptIds 需要删除的门店主键集合
     * @return 结果
     */
    public int deleteYjStoreByDeptIds(Long[] deptIds);

    /**
     * 删除门店信息
     *
     * @param deptId 门店主键
     * @return 结果
     */
    public int deleteYjStoreByDeptId(Long deptId);
}
